@@ -8,6 +8,9 @@ pub extern crate diesel;
 #[macro_use]
 pub extern crate diesel_derive_newtype;
 
+#[cfg(feature = "graphql")]
+pub extern crate async_graphql;
+
 pub extern crate serde;
 
 pub extern crate derive_more;
@@ -15,7 +18,7 @@ pub extern crate derive_more;
 #[macro_export]
 macro_rules! derive_id {
 	($id_newtype:item) => {
-		#[cfg_attr(feature = "graphql", derive(async_graphql::NewType))]
+		#[cfg_attr(feature = "graphql", derive($crate::async_graphql::NewType))]
 		#[cfg_attr(
 			not(feature = "graphql"),
 			derive($crate::derive_more::From, $crate::derive_more::Into)
@@ -24,7 +27,7 @@ macro_rules! derive_id {
 			feature = "diesel-id",
 			derive($crate::diesel_derive_newtype::DieselNewType)
 		)]
-		#[cfg_attr(feature = "diesel-id", derive(Identifiable))]
+		#[cfg_attr(feature = "diesel-id", derive($crate::diesel::Identifiable))]
 		#[derive(
 			$crate::derive_more::Display,
 			$crate::serde::Deserialize,
